# gqxls

*<u>A package for daily ues.</u>*

## A. Functions

### 1. Convert PDF to image

### 2. Get the specified directory suffix file absolute directory

### 3. Generate specified random string

## B. Long term plan
The package requires the following free softwares to work as expected:
- pillow
- pymupdf

## Changelog

*0.0.7*
- Modify some functions.

*0.0.6*
- Modify some functions.

*0.0.5*
- Fix PIP failed to install.